@@ -37,14 +37,14 @@ class MiniCluster(object):
     Example without :mod:`snakebite.client <client>`
 
     >>> from snakebite.minicluster import MiniCluster
-    >>> cluster = Minicluster("/path/to/test/files")
+    >>> cluster = MiniCluster("/path/to/test/files")
     >>> ls_output = cluster.ls(["/"])
 
     Example with :mod:`snakebite.client <client>`
 
     >>> from snakebite.minicluster import MiniCluster
     >>> from snakebite.client import Client
-    >>> cluster = Minicluster("/path/to/test/files")
+    >>> cluster = MiniCluster("/path/to/test/files")
     >>> client = Client('localhost', cluster.port)
     >>> ls_output = client.ls(["/"])
 
@@ -61,6 +61,8 @@ class MiniCluster(object):
         '''
         :param testfiles_path: Local path where test files can be found. Mainly used for ``put()``
         :type testfiles_path: string
+        :param start_cluster: start a MiniCluster on initialization. If False, this class will act as an interface to the ``hadoop fs`` command
+        :type start_cluster: boolean
         '''
         self._testfiles_path = testfiles_path
         self._hadoop_home = os.environ['HADOOP_HOME']
